@@ -1,14 +1,26 @@
 """Implement the ability for tasks to persist."""
+from typing import Any
+from typing import Dict
+from typing import Optional
+from typing import TYPE_CHECKING
+
 from _pytask.config import hookimpl
 from _pytask.dag import node_and_neighbors
-from _pytask.enums import ColorCode
+from _pytask.database import update_states_in_database
 from _pytask.exceptions import NodeNotFoundError
-from _pytask.mark import get_specific_markers_from_task
+from _pytask.mark_utils import get_specific_markers_from_task
 from _pytask.outcomes import Persisted
+from _pytask.outcomes import TaskOutcome
+
+
+if TYPE_CHECKING:
+    from _pytask.session import Session
+    from _pytask.nodes import MetaTask
+    from _pytask.report import ExecutionReport
 
 
 @hookimpl
-def pytask_parse_config(config):
+def pytask_parse_config(config: Dict[str, Any]) -> None:
     """Add the marker to the configuration."""
     config["markers"]["persist"] = (
         "Prevent execution of a task if all products exist and even if something has "
@@ -20,7 +32,7 @@ def pytask_parse_config(config):
 
 
 @hookimpl
-def pytask_execute_task_setup(session, task):
+def pytask_execute_task_setup(session: "Session", task: "MetaTask") -> None:
     """Exit persisting tasks early.
 
     The decorator needs to be set and all nodes need to exist.
@@ -44,13 +56,16 @@ def pytask_execute_task_setup(session, task):
 
 
 @hookimpl
-def pytask_execute_task_process_report(report):
+def pytask_execute_task_process_report(
+    session: "Session", report: "ExecutionReport"
+) -> Optional[bool]:
     """Set task status to success.
 
     Do not return ``True`` so that states will be updated in database.
 
     """
     if report.exc_info and isinstance(report.exc_info[1], Persisted):
-        report.success = True
-        report.symbol = "p"
-        report.color = ColorCode.SUCCESS
+        report.outcome = TaskOutcome.PERSISTENCE
+        update_states_in_database(session.dag, report.task.name)
+        return True
+    return None
